@@ -32,13 +32,15 @@ sub add_file {
 sub finish {
     my $self           = shift;
     my $invindex       = $self->{invindex};
+    my $filename       = $self->{filename};
     my @files_to_merge = keys %{ $self->{entries} };
     croak('no entries defined') unless @files_to_merge;
 
     # ensure that the file only gets written once; open the outfile
     croak('merge already performed') if $self->{merged};
     $self->{merged} = 1;
-    my $outstream = $invindex->open_outstream( $self->{filename} );
+    $invindex->delete_file($filename) if $invindex->file_exists($filename);
+    my $outstream = $invindex->open_outstream($filename);
 
     # write number of files, plus data_offset placeholders
     my @to_write = map { ( 0, $_ ) } @files_to_merge;
@@ -83,11 +85,11 @@ original files are not deleted, so cleanup must be done externally.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.162.
+See L<KinoSearch|KinoSearch> version 0.164.
 
 =end devdocs
 =cut
