@@ -62,8 +62,13 @@ sub write_postings {
         invindex => $invindex,
         seg_name => $seg_name,
     );
-    my $frq_out = $invindex->open_outstream("$seg_name.frq");
-    my $prx_out = $invindex->open_outstream("$seg_name.prx");
+    my $frq_file = "$seg_name.frq";
+    my $prx_file = "$seg_name.prx";
+    for ( $frq_file, $prx_file ) {
+        $invindex->delete_file($_) if $invindex->file_exists($_);
+    }
+    my $frq_out = $invindex->open_outstream($frq_file);
+    my $prx_out = $invindex->open_outstream($prx_file);
 
     _write_postings( $self->{sort_pool}, $tinfos_writer, $frq_out, $prx_out );
 
@@ -436,11 +441,11 @@ positional data files, plus feeds data to TermInfosWriter.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.163.
+See L<KinoSearch|KinoSearch> version 0.164.
 
 =end devdocs
 =cut
