@@ -85,7 +85,7 @@ sub init_instance {
 sub open_outstream {
     my ( $self, $filename ) = @_;
     my $filepath = catfile( $self->{path}, $filename );
-    sysopen( my $fh, $filepath, O_CREAT | O_RDWR | O_NONBLOCK | O_EXCL )
+    sysopen( my $fh, $filepath, O_CREAT | O_RDWR | O_EXCL )
         or confess("Couldn't open file '$filepath': $!");
     binmode($fh);
     return KinoSearch::Store::OutStream->new($fh);
@@ -193,10 +193,10 @@ invindex should be opened.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.162.
+See L<KinoSearch|KinoSearch> version 0.164.
 
 =cut
